==> tine20-allinone_2020.03.4.tar.bz2: Addressbook/js/Addressbook-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: cs\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Firemní kotaktní údaje"

, "Organisation / Unit"
: "Organizace / Útvar"

, "Business Address"
: "Firemní adresa"

, "Email"
: "E-mail"

, "Telephone Work"
: "Služební telefon"

, "Telephone Cellphone"
: "Mobilní telefon"

, "Telephone Car"
: "Telefon do auta"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Pager"

, "URL"
: "URL"

, "Role"
: "Funkce"

, "Room"
: "Místnost"

, "Assistant"
: "Asistentka"

, "Assistant Telephone"
: "Telefon asistentky"

, "Private Contact Data"
: "Soukromé kontaktní údaje"

, "Private Address"
: "Soukromá adresa"

, "Email Home"
: "Email domů"

, "Telephone Home"
: "Telefon domů"

, "Telephone Cellphone Private"
: "Soukromý mobilní telefon"

, "Telephone Fax Home"
: "Fax domů"

, "URL Home"
: "Domácí URL"

, "Other Data"
: "Ostatní údaje"

, "Birthday"
: "Narozeniny"

, "Job Title"
: "Povolání"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  ""
 ,""
 ,""
 ,""

]
, "Percent"
: ""

, "Description"
: "Popis"

, "Members"
: ""

, "Type"
: "Typ"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Adresář"
 ,"Adresáře"
 ,"Adresářů"
 ,"Adresářů"

]
, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakty"
 ,"Kontaktů"
 ,"Kontaktů"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Stát"

, "City"
: "Město"

, "Postalcode"
: "PSČ"

, "Region"
: "Region / Kraj"

, "Street"
: "Ulice"

, "Street 2"
: "Ulice 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Stát (privátní adresa)"

, "City (private)"
: "Město (privátní adresa)"

, "Postalcode (private)"
: "PSČ (privátní adresa)"

, "Region (private)"
: "Region / Kraj (privátní adresa)"

, "Street (private)"
: "Ulice (privátní adresa)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (privátní)"

, "Free/Busy URI"
: ""

, "Geo"
: "GPS souřadnice"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""
 ,""
 ,""

]
, "Note"
: "Poznámka"

, "Last Name"
: "Příjmení"

, "Display Name"
: "Zobrazované jméno"

, "Full Name"
: "Celé jméno"

, "First Name"
: "Křestní jméno"

, "Middle Name"
: "Prostřední jméno"

, "Title"
: "Titul"

, "Suffix"
: "Dodatek za jménem"

, "Company"
: "Firma"

, "Unit"
: "Útvar"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Pracovní funkce"

, "Salutation"
: "Oslovení"

, "syncBackendIds"
: ""

, "Car phone"
: "Telefon do auta"

, "Mobile"
: "Mobil"

, "Mobile (private)"
: "Mobil (privátní)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (privátní)"

, "Phone (private)"
: "Telefon (privátní)"

, "Pager"
: "Pager"

, "Phone"
: "Telefon"

, "Timezone"
: "Časová zóna"

, "Web"
: "WWW"

, "URL (private)"
: "URL (privátní)"

, "Label"
: ""

, "Lists"
: ""

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Kontaktní informace"

, "Company Address"
: "Firemní adresa"

, "New Contact"
: ""

, "ID"
: ""

, "Name"
: ""

, "Structure, Structures"
: [
  ""
 ,""
 ,""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Importovat kontakty"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Soukromé"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Štítky"

, "List Roles"
: ""

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "E-Mail"
: "E-mail"

, "E-Mail (private)"
: "E-mail (privátní)"

, "Web (private)"
: ""

, "Contacts"
: "Kontakty"

, "Addressbooks"
: "Adresáře"

, "User Account"
: "Uživatelský účet"

, "Quick Search"
: ""

, "Postal Code"
: "PSČ"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Vytvořeno"

, "Created By"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""
 ,""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""
 ,""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Vložit popis"

, "{0} must be given"
: ""

, "Member of List"
: ""

, "Map"
: "Mapa"

, "Company address"
: ""

, "Private address"
: ""

, "CardDAV URL"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Osobní informace"

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Všechny kontakty"

, "Default Addressbook"
: "Výchozí adresář"

, "The default addressbook for new contacts"
: "Výchozí adresář pro nové kontakty"

, "Default Favorite"
: "Výchozí oblíbené položky kontaktů"

, "The default favorite which is loaded on addressbook startup"
: "Výchozí oblíbené položky, které jsou načteny při spuštění adresáře"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Pan"

, "Ms"
: "Paní"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "manage shared addressbooks"
: "spravovat sdílené adresáře"

, "Create new shared addressbook folders"
: "Vytvořit nové sdílené složky adresáře"

, "manage shared addressbook favorites"
: "spravovat sdílené oblíbené položky adresáře"

, "Create or update shared addressbook favorites"
: "Vytvořit nebo aktualizovat sdílené oblíbené položky adresáře"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""
 ,""
 ,""

]
, "%s's personal addressbook"
: "Osobní adresář uživatele %s"

, "All contacts I have read grants for"
: "Všechny kontakty, které jsem oprávněn číst"

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Internal Contacts"
: "Interní kontakty"

, "List"
: ""

, "Addressbook"
: "Adresář"

, "Contact"
: "Kontakt"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Mapa"

, "Preferred Address"
: ""

, "Personal Information"
: "Osobní informace"

, "Salutation"
: "Oslovení"

, "Title"
: "Titul"

, "Short Name"
: ""

, "First Name"
: "Křestní jméno"

, "Middle Name"
: "Prostřední jméno"

, "Last Name"
: "Příjmení"

, "Company"
: "Firma"

, "Unit"
: "Útvar"

, "Display Name"
: "Zobrazované jméno"

, "Industry, Industries"
: [
  ""
 ,""
 ,""
 ,""

]
, "Job Title"
: "Povolání"

, "Birthday (private)"
: ""

, "Contact Information"
: "Kontaktní informace"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefon (privátní)"

, "Mobile (private)"
: "Mobil (privátní)"

, "Fax (private)"
: "Fax (privátní)"

, "E-Mail"
: "E-mail"

, "E-Mail (private)"
: "E-mail (privátní)"

, "Web"
: "WWW"

, "Company Address"
: "Firemní adresa"

, "Street"
: "Ulice"

, "Street 2"
: "Ulice 2"

, "Region"
: "Region / Kraj"

, "Postal Code"
: "PSČ"

, "City"
: "Město"

, "Country"
: "Stát"

, "Private Address"
: "Soukromá adresa"

, "Description"
: "Popis"

, "Enter description"
: "Vložit popis"

, "Groups"
: ""

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakty"
 ,"Kontaktů"
 ,"Kontaktů"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: ""

, "New Contact"
: ""

, "Addressbook, Addressbooks"
: [
  "Adresář"
 ,"Adresáře"
 ,"Adresářů"
 ,"Adresářů"

]
, "ID"
: ""

, "Name"
: ""

, "Structure, Structures"
: [
  ""
 ,""
 ,""
 ,""

]
, "Resources"
: ""

, "Private"
: "Soukromé"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""
 ,""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""
 ,""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Dodatek za jménem"

, "Birthday"
: "Narozeniny"

, "Job Role"
: "Pracovní funkce"

, "Room"
: "Místnost"

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "Web (private)"
: ""

, "Contacts"
: "Kontakty"

, "Addressbooks"
: "Adresáře"

, "User Account"
: "Uživatelský účet"

, "Quick Search"
: ""

, "Type"
: "Typ"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Vytvořeno"

, "Created By"
: ""

, "List, Lists"
: [
  ""
 ,""
 ,""
 ,""

]
, "Lists"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""
 ,""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""
 ,""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Importovat kontakty"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Štítky"

, "Full Name"
: "Celé jméno"

, "Postalcode"
: "PSČ"

, "Street (private)"
: "Ulice (privátní adresa)"

, "City (private)"
: "Město (privátní adresa)"

, "Region (private)"
: "Region / Kraj (privátní adresa)"

, "Postalcode (private)"
: "PSČ (privátní adresa)"

, "Country (private)"
: "Stát (privátní adresa)"

, "Email"
: "E-mail"

, "Car phone"
: "Telefon do auta"

, "Pager"
: "Pager"

, "Email (private)"
: "Email (privátní)"

, "URL (private)"
: "URL (privátní)"

, "Note"
: "Poznámka"

, "Timezone"
: "Časová zóna"

, "Geo"
: "GPS souřadnice"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: ""

, "Private address"
: ""

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Všechny kontakty"

, "Default Addressbook"
: "Výchozí adresář"

, "The default addressbook for new contacts"
: "Výchozí adresář pro nové kontakty"

, "Default Favorite"
: "Výchozí oblíbené položky kontaktů"

, "The default favorite which is loaded on addressbook startup"
: "Výchozí oblíbené položky, které jsou načteny při spuštění adresáře"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Pan"

, "Ms"
: "Paní"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "Osobní adresář uživatele %s"

, "Business Contact Data"
: "Firemní kotaktní údaje"

, "Organisation / Unit"
: "Organizace / Útvar"

, "Business Address"
: "Firemní adresa"

, "Telephone Work"
: "Služební telefon"

, "Telephone Cellphone"
: "Mobilní telefon"

, "Telephone Car"
: "Telefon do auta"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Pager"

, "URL"
: "URL"

, "Role"
: "Funkce"

, "Assistant"
: "Asistentka"

, "Assistant Telephone"
: "Telefon asistentky"

, "Private Contact Data"
: "Soukromé kontaktní údaje"

, "Email Home"
: "Email domů"

, "Telephone Home"
: "Telefon domů"

, "Telephone Cellphone Private"
: "Soukromý mobilní telefon"

, "Telephone Fax Home"
: "Fax domů"

, "URL Home"
: "Domácí URL"

, "Other Data"
: "Ostatní údaje"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Interní kontakty"

, "All contacts I have read grants for"
: "Všechny kontakty, které jsem oprávněn číst"

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "spravovat sdílené adresáře"

, "Create new shared addressbook folders"
: "Vytvořit nové sdílené složky adresáře"

, "manage shared addressbook favorites"
: "spravovat sdílené oblíbené položky adresáře"

, "Create or update shared addressbook favorites"
: "Vytvořit nebo aktualizovat sdílené oblíbené položky adresáře"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""
 ,""
 ,""

]
, "Industry"
: ""

, "Contact"
: "Kontakt"

, "Addressbook"
: "Adresář"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
